Package: multicool
Type: Package
Title: Permutations of Multisets in Cool-Lex Order
Version: 1.0.1
Date: 2024-02-05
Author: James Curran, Aaron Williams, Jerome Kelleher, Dave Barber
Maintainer: James Curran <j.curran@auckland.ac.nz>
Description: A set of tools to permute multisets without loops or hash tables and to generate integer partitions. The permutation functions are based on C code from Aaron Williams. Cool-lex order is similar to colexicographical order. The algorithm is described in Williams, A. Loopless Generation of Multiset Permutations by Prefix Shifts. SODA 2009, Symposium on Discrete Algorithms, New York, United States. The permutation code is distributed without restrictions. The code for stable and efficient computation of multinomial coefficients comes from Dave Barber. The code can be download from <http://tamivox.org/dave/multinomial/index.html> and is distributed without conditions. The package also generates the integer partitions of a positive, non-zero integer n. The C++ code for this is based on Python code from Jerome Kelleher which can be found here <https://jeromekelleher.net/category/combinatorics.html>. The C++ code and Python code are distributed without conditions.
URL: https://github.com/jmcurran/multicool
BugReports: https://github.com/jmcurran/multicool/issues
Encoding: UTF-8
License: GPL-2
Depends: methods, Rcpp (>= 0.11.2)
LinkingTo: Rcpp
RcppModules: Multicool
RoxygenNote: 7.2.3
NeedsCompilation: yes
Packaged: 2024-02-05 01:22:16 UTC; james
Repository: CRAN
Date/Publication: 2024-02-05 12:20:06 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 09:13:35 UTC; unix
Archs: multicool.so.dSYM
