# Generated by roxygen2: do not edit by hand

export(B)
export(Bell)
export(S2)
export(Stirling2)
export(allPerm)
export(genComp)
export(initMC)
export(multinom)
export(nextPerm)
import(Rcpp)
import(methods)
useDynLib(multicool)
